# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['oanda_candles']

package_data = \
{'': ['*']}

install_requires = \
['forex-types>=0.0.6,<0.0.7',
 'magic-kind>=0.2.2,<0.3.0',
 'oandapyV20>=0.6.3,<0.7.0',
 'requests>=2.23.0,<3.0.0',
 'time-int>=0.0.9,<0.0.10']

setup_kwargs = {
    'name': 'oanda-candles',
    'version': '0.1.0',
    'description': 'Oanda forex candle API built on top of oandapyV20',
    'long_description': '# oanda-candles\nClient to make getting Oanda candle data easy.\n\n### Quick Example\n```python\nimport os\nfrom oanda_candles import CandleClient, Pair, Gran\n\ntoken = os.getenv("OANDA_TOKEN")\n\n# Initialize Client with token, real as False for practice account.\nclient = CandleClient(token, real=False)\n\n# Initialize collector for Euro/US Dollar 4 hour candles.\ncollector = client.get_collector(Pair.EUR_USD, Gran.H4)\n\n# Print the opening and closing bid price of the most recent 100 candles.\ncandles = collector.grab(100)\nfor candle in candles:\n    print(f"{candle.time.get_pretty()}: Open bid: {candle.bid.o} Close bid: {candle.bid.c}")\n\n# Get list of 300 candles from 8000 candles back\nspecial_300 = collector.grab_offset(8000, 300)\n```\n\n### Public Classes in this Package\n| Class | Description\n| ----- |:-----|\n| Candle | Data about one candle containing a start time and three Ohlc objects for the bid, mid, and ask prices |\n| CandleClient | Collection of one CandleCollector for each combination of `pair` and `gran` |\n| CandleCollector | For grabbing candles for a specific `pair` and `gran` |\n| CandleMeister | Provides a single CandleCollector so one does not have to pass it around between modules |\n| Gran | Candle granularity (duration), one of the spefic values allowed by Oanda\'s API such as Gran.H6 for six hour |\n| Ohlc | Contains open, high, low, and closing prices as attrs `o`, `h`, `l`, and `c` |\n| Pair | One of 28 forex currency pairs. Can be specified like `Pair.EUR_USD` or `Pair("eurusd")` |\n| TimeInt | Integer subclass representing time since Jan 1, 1970 in UTC, candles have this as their `time` attribute |\n\n\n### Some Features\n1. Candle data is cached automatically so calling `grab` or `grab_offset` for same candles do not require another server requests.\n1. However, when candles are grabbed, the cache is updated to include the most recent candles provided at least\nthree seconds have passed since the last time they were updated.\n1. The Candle objects returned have the bid, mid, and ask prices and have times expressed as UTC epoch integers.\n1. Candles are aligned to reasonable offset defaults (month candles start at start of month in UTC).\n1. Candle alignment is preset to always start days and month candles on the start of the day and month UTC.\n\n### Some Limitations.\n1. Requires secret Oanda Access token to initialize client.\n1. Only candle granularity levels supported by Oanda\'s V20 RestfulAPI are available.\n1. Only forex pairs (instruments) supported by the forex-types package are supported (The 28 pair combinations for the 8 major currencies).\n1. Not all the options of Oanda\'s V20 candle endpoint are available. Rather reasonable values are already preset.\n(considering the very odd defaults and the confusing way the options work, this is kind of a feature type limitation,\nstill in a future version these likely should be made configurable for any masachists that want to mess with them).\n\n\n\n### Steps followed by `grab` and `grab_offset` methods\nWhen either the `grab` or `grab_offset` methods are called on a particular `CandleCollector` object, it:\n1. Makes sure candle cache is up to date with latest candles by querying Oanda if its been longer than 3 seconds since this was last done.\n1. If the candles in the cache do not go back far enough to provide the number requested get older candles from Oanda until it does.\n1. Return the requested candles, while keeping the cached list for the next grab calls.\n\n\n#### CAVEAT:\nThis is still a beta type package--although between 0.0.10 and 0.1.0 it became somewhat less beta-ish.\n\n#### Version history.\n\nnew in version 0.1.0:\n1. Reliance on opandaV20 package was dropped in favor of using requests package directly.\n1. Everything was refactored into smaller simpler less "exploratory" code.\n1. Updating TimeInt package to 0.0.9 which is entirely UTC, without any accidental local times popping in.\n1. Month candles are aligned right at start of month UTC. And day candles at start of day and so forth.\n1. CandleSequence class which had no real utility compared to highe level grab classes were refactored out. \n1. Only tested refactoring by hand, unittests have to be rewritten (since they were full of funky time alignment that we no longer have.)\n\nnew in version 0.0.10:\n1. Updated time-int dependency from 0.0.6 to 0.0.7.\n\nnew in version 0.0.9:\n1. CandleMeister and CandleClient now have a method to get the collector they use\nfor a specific pair and granularity.\n1. Updated some dependencies to latest versions.\n\nnew in version 0.0.8:\n1. Added CandleClient to manage multiple CandleCollector objects from one object.\n1. Plus a CandleMeister that wraps a single CandleClient for easy global access\n1. Fixed a bug that was causing too many requests when they were not needed.\n1. Had idea for `tail` method as a variant on `grab` method, where it returns only\nthe newest candle information since the last call to eitehr `grab` or `tail`. Made\na place holder for it, but not implementing it yet.\n1. Still behind on unit tests, but still was able to do sand-box testing with market open.\n--which is how I found and fixed bug above. This package is still far from prime time ready.\n\n\nnew in version 0.0.7:\n1. The `CandleSequence` has been cleaned up and plans to add merging have been abandoned.\n1. The `Candle` class no longer has `__lt__` overloaded and `__eq__` is now based on all the values being equal rather than just the candle time.\n1. A new `CandleCollector` class is added which is like a higher level `CandleSequence` specifically designed for chart applications that always want a specific number of latest candles. \n1. No unit testing has been added for these changes, they have only been sand-boxed, so they may not work as advertised. Also the market was closed when I sand-boxed `CandleCollector`, so some of its heursitics have not even been sand-box tested yet.\n\n\n\n### About Oanda Access Tokens\nUsing this package requires an access token to a user\'s\nOanda brokerage account. This module only uses the token to\nrequest candle data, but such tokens can be used to make\ntrades on the account. It is recommended that access\ntokens from a demo as opposed to a live accounts be used.\n \nDemo account tokens can be generated by a signed in user here:\n\nhttps://www.oanda.com/demo-account/tpa/personal_token\n\n**Warning**: Oanda sometimes takes their API down for maintenance.\nThis seems to mostly occur shortly after the market closes at the end of\nthe trading week (at 5pm New York time). During the maintenance you\nmay get a 401 http response that looks like your token is not valid\neven if it is.\n\n',
    'author': 'Andrew Allaire',
    'author_email': 'andrew.allaire@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aallaire/oanda-candles',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)
